@@ -60,8 +60,7 @@ class PhysicalObject:
 
     Notes
     -----
-    * **Reference in Korean**: 물리 객체들의 기본 클래스, 물리적 좌표정보를 갖고 있다. 
-
+    * **Reference in Korean**: 물리 객체들의 기본 클래스, 물리 좌표 정보를 갖고 있다. 
 
     """
 
@@ -91,7 +90,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 이름.
+    **Reference in Korean**: 객체의 이름.
     """
 
 
@@ -114,7 +113,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 좌표.
+    **Reference in Korean**: 객체의 좌표.
     """
 
 
@@ -129,7 +128,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 master.
+    **Reference in Korean**: 객체의 master (배열 element 또는 pin 객체들의 master 객체에 연결).
     """
 
 
@@ -144,7 +143,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 속성.
+    **Reference in Korean**: 객체의 속성.
     """
 
 
@@ -168,7 +167,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 주요좌표들.
+    **Reference in Korean**: 객체의 주요 좌표들을 담고 있는 dict.
     """
 
 
@@ -188,7 +187,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 left pointer.
+    **Reference in Korean**: 객체의 left-center 좌표.
     """
 
 
@@ -207,7 +206,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 right pointer.
+    **Reference in Korean**: 객체의 right-center 좌표.
     """ 
 
 
@@ -226,7 +225,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 top pointer.
+    **Reference in Korean**: 객체의 top-center 좌표.
     """
 
 
@@ -245,7 +244,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 bottom pointer.
+    **Reference in Korean**: 객체의 bottom-center 좌표.
     """ 
 
 
@@ -264,7 +263,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 center pointer.
+    **Reference in Korean**: 객체의 center-center 좌표.
     """ 
 
 
@@ -283,7 +282,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 bottom_left pointer.
+    **Reference in Korean**: 객체의 bottom-left 좌표.
     """
 
 
@@ -302,7 +301,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 bottom_right pointer.
+    **Reference in Korean**: 객체의 bottom-right 좌표.
     """ 
 
 
@@ -321,7 +320,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 top_left pointer.
+    **Reference in Korean**: 객체의 top-left 좌표.
     """
 
 
@@ -340,7 +339,7 @@ class PhysicalObject:
 
     Notes
     -----
-    **Reference in Korean**: Physical 객체의 top_right pointer.
+    **Reference in Korean**: 객체의 top-right 좌표.
     """
 
 
@@ -360,7 +359,7 @@ class PhysicalObject:
         
         Notes
         -----
-        **Reference in Korean**: numpy.ndarray: Physical 객체의 bbox.
+        **Reference in Korean**: numpy.ndarray: 객체의 bbox (bounding box).
         """
         return np.sort(np.array([self.xy[0, :], self.xy[1, :]]), axis=0)
 
@@ -394,19 +393,15 @@ class PhysicalObject:
         
         Notes
         -----
-        **Reference in Korean**:     PhysicalObject 클래스의 생성자 함수.
+        **Reference in Korean**: PhysicalObject 클래스의 생성자.
 
         파라미터
 
-        xy(numpy.ndarray): 객체의 물리적 좌표, bbox
+        xy(numpy.ndarray): 객체의 물리적 좌표 (bbox).
 
-        name(str): 객체의 이름
+        name(str): 객체의 이름.
 
-        params(dict): 속성을 갖고 있는 Dictionary
-
-        반환값
-
-        laygo2.PhysicalObject
+        params(dict): 객체의 주요 속성을 갖고 있는 dict.
 
         """
 
@@ -506,7 +501,7 @@ class IterablePhysicalObject(PhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체의 하위 구성원.
+    **Reference in Korean**: 객체의 하위 구성원을 담고 있는 list.
 
     """
     def _get_xy(self):
@@ -539,7 +534,7 @@ class IterablePhysicalObject(PhysicalObject):
         
         Notes
         -----
-        **Reference in Korean**:     numpy.ndarray: 객체의 element의 shape.
+        **Reference in Korean**: numpy.ndarray: 객체의 element의 배열 크기.
         """
         if self.elements is None:
             return None
@@ -558,16 +553,12 @@ class IterablePhysicalObject(PhysicalObject):
             The name of the object.
         params : dict
             The dictionary containing attributes of the object.
-        elements : dict
+        elements : list
             The dictionary containing element objects that compose the object.
         
         Returns
         -------
-        laygo2.IterablePhysicalObject
-
-        See Also
-        --------
-        Class PhysicalObject
+        IterablePhysicalObject
 
         Example
         --------
@@ -584,25 +575,18 @@ class IterablePhysicalObject(PhysicalObject):
         
         Notes
         -----
-        **Reference in Korean**:     IterablePhysicalObject 클래스의 생성자 함수.
+        **Reference in Korean**:  IterablePhysicalObject 클래스의 생성자.
 
         파라미터
 
-        xy(numpy.ndarray): 객체의 물리적 좌표, bbox
+        xy(numpy.ndarray): 객체의 물리 좌표 (bbox).
 
-        name(str): 객체의 이름
+        name(str): 객체의 이름.
 
-        params(dict): 속성을 갖는 Dictionary
+        params(dict): 객체의 주요 속성이 담긴 dict.
 
-        elements(dict): 단위 객체를 갖는 Dictionary
+        elements(list): 객체의 구성 요소 객체들(elements)이 담긴 list.
 
-        반환값
-
-        laygo2.IterablePhysicalObject
-
-        참조
-
-        Class PhysicalObject
         """
         PhysicalObject.__init__(self, xy=xy, name=name, params=params)
         if elements is None:
@@ -760,6 +744,7 @@ class Rect(PhysicalObject):
     Notes
     -----
     **Reference in Korean**: 사각형 객체 클래스.
+
     """
 
     layer = None
@@ -774,7 +759,7 @@ class Rect(PhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체의 Layer 정보.
+    **Reference in Korean**: 객체의 layer 정보 [name, purpose].
     """
 
 
@@ -790,7 +775,7 @@ class Rect(PhysicalObject):
     
     Notes
     -----
-    **Reference in Korean**: 객체의 노드명.
+    **Reference in Korean**: 객체의 노드 이름.
     """
 
 
@@ -809,7 +794,7 @@ class Rect(PhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체의 수평방향으로의 확장값.
+    **Reference in Korean**: 객체의 기존 좌표로부터 수평 방향으로의 확장값.
     """
 
 
@@ -828,7 +813,7 @@ class Rect(PhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체의 수직방향으로의 확장값.
+    **Reference in Korean**: 객체의 기존 좌표로부터 수직 방향으로의 확장값.
     """
 
 
@@ -844,7 +829,7 @@ class Rect(PhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체의 color.
+    **Reference in Korean**: 객체의 color (multi-patterning ID).
     """
 
     @property
@@ -863,7 +848,7 @@ class Rect(PhysicalObject):
 
         Notes
         -----
-        **Reference in Korean**:     int: 객체의 높이.
+        **Reference in Korean**: int: 객체의 높이.
         """
         return abs(self.xy[0, 1] - self.xy[1, 1])
 
@@ -883,7 +868,7 @@ class Rect(PhysicalObject):
 
         Notes
         -----
-        **Reference in Korean**:     int: 객체의 폭.
+        **Reference in Korean**: int: 객체의 폭.
         """
         return abs(self.xy[0, 0] - self.xy[1, 0])
 
@@ -900,7 +885,7 @@ class Rect(PhysicalObject):
     @property
     def size(self):
         """
-        numpy.ndarray: The size of the object.
+        numpy.ndarray: The size of the object ([width, height]).
 
         Example
         --------
@@ -913,7 +898,7 @@ class Rect(PhysicalObject):
 
         Notes
         -----
-        **Reference in Korean**:     numpy.ndarray: 객체의 크기.
+        **Reference in Korean**: numpy.ndarray: 객체의 크기 ([폭, 높이]).
         """
         return np.array([self.width, self.height])
 
@@ -942,7 +927,7 @@ class Rect(PhysicalObject):
         
         Returns
         -------
-        laygo2.Pin
+        Rect
 
         See Also
         --------
@@ -964,25 +949,21 @@ class Rect(PhysicalObject):
 
         파라미터
 
-        xy(numpy.ndarray): 객체의 물리적 좌표, bbox
+        xy(numpy.ndarray): 객체의 물리 좌표 (bbox).
 
-        layer(list): 객체의 layer 정보
+        layer(list): 객체의 layer 정보.
 
-        hextension(int): 객체의 수평부 확장값
+        hextension(int): 객체의 수평 방향 확장값.
 
-        vextension(int): 객체의 수직 확장값
+        vextension(int): 객체의 수직 방향 확장값.
 
-        name(str): 객체의 이름
+        name(str): 객체의 이름.
 
-        netname(str): 객체의 노드 명
+        netname(str): 객체의 노드 명.
 
-        params(dict): 속성을 갖는 Dictionary [optional]
+        params(dict): 객체의 주요 속성을 갖는 dict [optional].
 
-        color(str): 객체의 color [optional]
-
-        반환값
-
-        laygo2.Pin
+        color(str): 객체의 color [optional].
 
         참조
 
@@ -1062,7 +1043,7 @@ class Path(PhysicalObject):
     
     Notes
     -----
-    **Reference in Korean**: list: 객체의 레이어 정보.
+    **Reference in Korean**: list: 객체의 레이어 정보 ([name, purpose]).
     """
 
 
@@ -1081,7 +1062,7 @@ class Path(PhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체의 노드명.
+    **Reference in Korean**: 객체의 노드 명.
     """
 
 
@@ -1106,7 +1087,7 @@ class Path(PhysicalObject):
 
     extension = 0
     """
-    int: The extension of the path object.
+    int: The extension of the path object from its endpoints.
 
     Example
     --------
@@ -1119,7 +1100,7 @@ class Path(PhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체의 확장값.
+    **Reference in Korean**: 객체의 양 끝점에서의 확장값.
     """
 
     @property
@@ -1154,11 +1135,7 @@ class Path(PhysicalObject):
 
         Returns
         -------
-        numpy.ndarray
-
-        See Also
-        --------
-        Class PhysicalObject
+        Path
 
         Example
         --------
@@ -1172,31 +1149,24 @@ class Path(PhysicalObject):
 
         Notes
         -----
-        **Reference in Korean**:     Path 객체 생성
+        **Reference in Korean**: Path 객체 생성.
 
         파라미터
 
-        xy(numpy.ndarray): 객체의 물리적 좌표, bbox
+        xy(numpy.ndarray): 객체의 물리 좌표 (bbox).
 
-        layer(list): 객체의 layer 정보
+        layer(list): 객체의 layer 정보.
 
-        width(int): 객체의 폭
+        width(int): 객체의 폭.
 
-        extension(int): 객체의 확장값
+        extension(int): 객체의 끝점에서의 확장 값.
 
-        name(str): 객체의 이름
+        name(str): 객체의 이름.
 
-        netname(str): 객체의 노드 명
+        netname(str): 객체의 노드 명.
 
-        params(dict): 속성을 갖는 Dictionary
+        params(dict): 객체의 주요 속성을 갖는 dict.
 
-        반환값
-
-        numpy.ndarray
-
-        참조
-
-        Class PhysicalObject
         """
         self.layer = layer
         self.width = width
@@ -1233,7 +1203,7 @@ class Pin(IterablePhysicalObject):
     >>> pin0.layer 
     ['M1', 'drawing']
     
-    numpy.ndarray: 객체의 Layer 정보.
+    numpy.ndarray: 객체의 layer 정보 ([name, purpose]).
     """
 
 
@@ -1247,7 +1217,7 @@ class Pin(IterablePhysicalObject):
     >>> pin0.netname 
     “net0”
     
-    str: 객체의 노드명.
+    str: 객체의 노드 명.
     """
 
 
@@ -1334,11 +1304,7 @@ class Pin(IterablePhysicalObject):
         
         Returns
         -------
-        laygo2.Pin
-
-        See Also
-        --------
-        Class IterablePhysicalObject
+        Pin
 
         Example
         --------
@@ -1347,31 +1313,23 @@ class Pin(IterablePhysicalObject):
         <laygo2.object.physical.Pin object at 0x0000017DBDA4F508> name: None,
          class: Pin, xy: [[0, 0], [100, 100]], params: {'direction': 'input’},
          layer: ['M1', 'drawing'], netname: net0, shape: None, master: None
-
-        
+       
         Notes
         -----
         **Reference in Korean**:     Pin 클래스의 생성자 함수
 
         파라미터
 
-        xy(numpy.ndarray): 객체의 물리적 좌표, bbox
+        xy(numpy.ndarray): 객체의 물리적 좌표 (bbox).
 
-        layer(list): 객체의 layer 정보
+        layer(list): 객체의 layer 정보 ([name, purpose]).
 
-        name(str): 객체의 이름
+        name(str): 객체의 이름.
 
-        netname(str): 객체의 노드 명
+        netname(str): 객체의 노드 명.
 
-        params(dict): 속성을 갖는 Dictionary
+        params(dict): 객체의 주요 속성을 갖는 dict.
 
-        반환값
-
-        laygo2.Pin
-
-        참조
-
-        Class IterablePhysicalObject
         """
         self.layer = np.asarray(layer)
         if netname is None:
@@ -1416,7 +1374,7 @@ class Text(PhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체의 Layer 정보.
+    **Reference in Korean**: 객체의 layer 정보 ([name, purpose]).
     """
 
 
@@ -1455,11 +1413,11 @@ class Text(PhysicalObject):
         
         Returns
         -------
-        laygo2.Text
+        Text
 
         See Also
         --------
-        Class PhysicalObject
+        PhysicalObject
 
         Example
         --------
@@ -1470,27 +1428,20 @@ class Text(PhysicalObject):
         
         Notes
         -----
-        **Reference in Korean**:     Text 클래스의 생성자 함수
+        **Reference in Korean**: Text 클래스의 생성자 함수.
 
         파라미터
 
-        xy(numpy.ndarray): 객체의 물리적 좌표, bbox
+        xy(numpy.ndarray): 객체의 물리적 좌표, bbox.
 
-        layer(list): 객체의 layer 정보
+        layer(list): 객체의 layer 정보.
 
-        text(str): 텍스트 내용
+        text(str): 텍스트 내용.
 
-        name(str): 객체의 이름
+        name(str): 객체의 이름.
 
-        params(dict): 속성을 갖는 Dictionary
+        params(dict): 객체의 주요 속성을 갖는 dict.
 
-        반환값
-
-        laygo2.Text
-
-        참조
-
-        Class PhysicalObject
         """
         self.layer = layer
         self.text = text
@@ -1605,7 +1556,7 @@ class Instance(IterablePhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체의 변환 속성.
+    **Reference in Korean**: 객체의 변환 속성 (R0, MX, MY 등).
     """
 
 
@@ -1633,7 +1584,7 @@ class Instance(IterablePhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체에 속한 핀들을 갖는 Dict.
+    **Reference in Korean**: 객체에 속한 핀들을 갖는 dict.
     """
 
     def _update_pins(self, xy_ofst):
@@ -1710,7 +1661,7 @@ class Instance(IterablePhysicalObject):
     @property
     def size(self):
         """
-        numpy.ndarray: The size of the object.
+        numpy.ndarray: The size of the object ([width, height]).
 
         Example
         --------
@@ -1726,7 +1677,7 @@ class Instance(IterablePhysicalObject):
 
         Notes
         -----
-        **Reference in Korean**:     numpy.ndarray: 객체의 크기.
+        **Reference in Korean**:     numpy.ndarray: 객체의 크기 ([width, height]).
         """
         if self.shape is None:
             return self.unit_size
@@ -1760,9 +1711,13 @@ class Instance(IterablePhysicalObject):
     .. image:: ../assets/img/object_physical_instance_pitch.png
       :height: 250
 
+    See Also
+    --------
+    Instance.spacing
+
     Notes
     -----
-    **Reference in Korean**: 배열로 구성된 객체의 단위객체간 간격.
+    **Reference in Korean**: 배열로 구성된 객체의 단위 객체(element)간 간격 (pitch).
     """
 
     def get_spacing(self):
@@ -1787,9 +1742,13 @@ class Instance(IterablePhysicalObject):
     .. image:: ../assets/img/object_physical_instance_spacing.png
       :height: 250
 
+    See Also
+    --------
+    Instance.pitch
+
     Notes
     -----
-    **Reference in Korean**: 배열로 구성된 객체의 단위객체간 간격.
+    **Reference in Korean**: 배열로 구성된 객체의 단위 객체(element)간 간격 (spacing).
     """
 
     @property
@@ -1885,7 +1844,7 @@ class Instance(IterablePhysicalObject):
         
         Returns
         -------
-        object (laygo2.Instance)
+        Instance
 
         See Also
         --------
@@ -1909,33 +1868,26 @@ class Instance(IterablePhysicalObject):
 
         파라미터
 
-        xy(numpy.ndarray): 객체의 주좌표 [x0, y0]
+        xy(numpy.ndarray): 객체의 주좌표 [x0, y0].
 
-        libname(str): 객체의 library 이름
+        libname(str): 객체의 library 이름.
 
-        cellname(str): 객체의 cell이름
+        cellname(str): 객체의 cell 이름.
 
-        shape(numpy.ndarray): elements 의 shape, [column, row]
+        shape(numpy.ndarray): elements의 배열 크기 ([column, row]).
 
-        pitch(numpy.ndarray): 배열로 구성된 객체의 하위객체간 간격
+        pitch(numpy.ndarray): 배열로 구성된 객체의 구성 요소 (element) 간격 (pitch).
 
-        transform(str): 객체의 변환 속성
+        transform(str): 객체의 변환 속성.
 
-        unit_size(list): 객체의 단위 크기
+        unit_size(list): 객체의 단위 크기.
 
-        pins(dict): 객체에 속한 핀들을 갖는 Dictionary
+        pins(dict): 객체에 속한 핀들을 갖는 dict.
 
-        name(str): 객체의 이름
+        name(str): 객체의 이름.
 
-        params(dict): 객체의 속성을 갖는 Dictionary
+        params(dict): 객체의 주요 속성을 갖는 dict.
 
-        반환값
-
-        object (laygo2.Instance)
-
-        참조
-
-        Class IterablePhysicalObject
         """
         # Assign parameters.
         xy = np.asarray(xy)
@@ -2047,7 +1999,7 @@ class VirtualInstance(Instance):  # IterablePhysicalObject):
 
     Notes
     -----
-    **Reference in Korean**: 객체를 구성하는 물리객체들을 갖고있는 Dict.
+    **Reference in Korean**: 객체를 구성하는 하위 물리 객체들(Rect, Path, Pin, Text, Instance 등)을 갖고 있는 dict.
     """
     # Dict[PhysicalObject] the elements that compose the virtual instance. Its keys represent the names of the elements.
 
@@ -2083,7 +2035,7 @@ class VirtualInstance(Instance):  # IterablePhysicalObject):
 
         Returns
         -------
-        object (laygo2.VirtualInstance)
+        laygo2.VirtualInstance
 
         See Also
         --------
@@ -2100,39 +2052,32 @@ class VirtualInstance(Instance):  # IterablePhysicalObject):
 
         Notes
         -----
-        **Reference in Korean**:     VirtualInstance 클래스의 생성자 함수
+        **Reference in Korean**: VirtualInstance 클래스의 생성자.
 
         파라미터
 
-        xy(numpy.ndarray): 객체의 주좌표 [x0, y0]
+        xy(numpy.ndarray): 객체의 주좌표 [x0, y0].
 
-        libname(str): 객체의 library 이름
+        libname(str): 객체의 library 이름.
 
-        cellname(str): 객체의 cell이름
+        cellname(str): 객체의 cell이름.
 
-        native_elements(dict): 객체를 구성하는 물리객체를 갖는 Dict
+        native_elements(dict): 객체를 구성하는 물리 객체를 갖는 dict.
 
-        shape(numpy.ndarray): elements 의 shape
+        shape(numpy.ndarray): elements의 배열 크기 ([col, row]).
 
-        pitch(numpy.ndarray): 배열로 구성된 객체의 하위객체간 간격 
+        pitch(numpy.ndarray): 배열로 구성된 객체의 하위 객체 (element)간의 간격.
 
-        transform(str): 객체의 변환 속성
+        transform(str): 객체의 변환 속성 (R0, MX, MY 등).
 
-        unit_size(list): 객체의 단위 크기
+        unit_size(list): 객체의 단위 크기.
 
-        pins(dict): 객체에 속한 핀들을 갖는 Dictionary
+        pins(dict): 객체에 속한 핀들을 갖는 dict.
 
-        name(str): 객체의 이름
+        name(str): 객체의 이름.
 
-        params(dict): 객체의 속성을 갖는 Dictionary
+        params(dict): 객체의 주요 속성을 갖는 dict.
 
-        반환값
-
-        object (laygo2.VirtualInstance)
-
-        참조
-
-        Class Instance
         """
         self.native_elements = native_elements
 
